@@ -135,6 +135,14 @@ public:
                                            m_osItf->pfnCachePolicyGetMemoryObject(
                                                       MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC,
                                                       m_osItf->pfnGetGmmClientContext(m_osItf)).DwordValue;
+        m_referncePictureMemoryObjectControlStateCtrlDecode.Value =
+                                           m_osItf->pfnCachePolicyGetMemoryObject(
+                                                      MOS_HW_RESOURCE_USAGE_DECODE_INPUT_REFERENCE,
+                                                      m_osItf->pfnGetGmmClientContext(m_osItf)).DwordValue;
+        m_referncePictureMemoryObjectControlStateCtrlEncode.Value =
+                                           m_osItf->pfnCachePolicyGetMemoryObject(
+                                                      MOS_HW_RESOURCE_USAGE_ENCODE_INPUT_RECON,
+                                                      m_osItf->pfnGetGmmClientContext(m_osItf)).DwordValue;
         m_macroblockIldbStreamoutBufferCtrl.Value = 
                                            m_osItf->pfnCachePolicyGetMemoryObject(
                                                       MOS_CODEC_RESOURCE_USAGE_MACROBLOCK_ILDB_STREAM_OUT_BUFFER_CODEC,
@@ -378,6 +386,8 @@ public:
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_intraRowStoreScratchBufferMemoryCtrl;
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_deblockingFilterRowStoreScratchMemoryCtrl;
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_referncePictureMemoryObjectControlStateCtrl;
+    MHW_MEMORY_OBJECT_CONTROL_PARAMS m_referncePictureMemoryObjectControlStateCtrlDecode;
+    MHW_MEMORY_OBJECT_CONTROL_PARAMS m_referncePictureMemoryObjectControlStateCtrlEncode;
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_macroblockIldbStreamoutBufferCtrl;
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_secondMacroblockIldbStreamoutBufferCtrl;
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_slicesizeStreamoutDataDestinationCtrl;
@@ -960,7 +970,7 @@ protected:
             InitMocsParams(resourceParams, &cmd.DirectMvBufferAttributes.DW0.Value, 1, 6);
         }
 
-        bool dmvPresent[CODEC_MAX_NUM_REF_FRAME] = { false };
+        bool dmvPresent[CODEC_AVC_NUM_REF_DMV_BUFFERS] = { false };
         for (auto i = 0; i < CODEC_MAX_NUM_REF_FRAME; i++)
         {
             if (params.pAvcPicIdx[i].bValid)
@@ -1249,14 +1259,10 @@ protected:
         }
         else
         {
-            for (auto i = 0, j = 0; i < (CODEC_MAX_NUM_REF_FRAME / 2); i++, j++)
-            {
-                cmd.Viewidlist1616Bits[i] = 0;
-            }
-        }
-        for (auto i = 0, j = 0; i < (CODEC_MAX_NUM_REF_FRAME / 4); i++, j++)
-        {
-            cmd.Vieworderlistl1168Bits[i] = 0;  //FirstEntry
+            // non-MVC usage
+            MOS_ZeroMemory(cmd.Viewidlist1616Bits, sizeof(cmd.Viewidlist1616Bits));
+            MOS_FillMemory(cmd.Vieworderlistl0168Bits, sizeof(cmd.Vieworderlistl0168Bits), 0xF);
+            MOS_FillMemory(cmd.Vieworderlistl1168Bits, sizeof(cmd.Vieworderlistl1168Bits), 0xF);
         }
 
         #define DO_FIELDS()                                                               \
