@@ -1505,6 +1505,15 @@ protected:
     {
     _MHW_SETCMD_CALLBASE(VDENC_CMD3);
 
+    cmd.DW1_2.VDENC_CMD3_DW1_BIT0  = params.vdencCmd3Par0[0];
+    cmd.DW1_2.VDENC_CMD3_DW1_BIT8  = params.vdencCmd3Par0[1];
+    cmd.DW1_2.VDENC_CMD3_DW1_BIT16 = params.vdencCmd3Par0[2];
+    cmd.DW1_2.VDENC_CMD3_DW1_BIT24 = params.vdencCmd3Par0[3];
+    cmd.DW1_2.VDENC_CMD3_DW2_BIT0  = params.vdencCmd3Par0[4];
+    cmd.DW1_2.VDENC_CMD3_DW2_BIT8  = params.vdencCmd3Par0[5];
+    cmd.DW1_2.VDENC_CMD3_DW2_BIT16 = params.vdencCmd3Par0[6];
+    cmd.DW1_2.VDENC_CMD3_DW2_BIT24 = params.vdencCmd3Par0[7];
+
     for (auto i = 0; i < 12; i++)
     {
         cmd.VDENC_CMD3_DW3_5[i] = params.vdencCmd3Par1[i];
@@ -1512,15 +1521,6 @@ protected:
     }
 
 #define DO_FIELDS()                                                 \
-    DO_FIELD(DW1_2, VDENC_CMD3_DW1_BIT0,  params.vdencCmd3Par0[0]); \
-    DO_FIELD(DW1_2, VDENC_CMD3_DW1_BIT8,  params.vdencCmd3Par0[1]); \
-    DO_FIELD(DW1_2, VDENC_CMD3_DW1_BIT16, params.vdencCmd3Par0[2]); \
-    DO_FIELD(DW1_2, VDENC_CMD3_DW1_BIT24, params.vdencCmd3Par0[3]); \
-    DO_FIELD(DW1_2, VDENC_CMD3_DW2_BIT0,  params.vdencCmd3Par0[4]); \
-    DO_FIELD(DW1_2, VDENC_CMD3_DW2_BIT8,  params.vdencCmd3Par0[5]); \
-    DO_FIELD(DW1_2, VDENC_CMD3_DW2_BIT16, params.vdencCmd3Par0[6]); \
-    DO_FIELD(DW1_2, VDENC_CMD3_DW2_BIT24, params.vdencCmd3Par0[7]); \
-                                                                    \
     DO_FIELD(DW10, VDENC_CMD3_DW10_BIT16, params.vdencCmd3Par3);    \
     DO_FIELD(DW10, VDENC_CMD3_DW10_BIT24, params.vdencCmd3Par4);    \
                                                                     \
